@@ -459,7 +459,9 @@ class DataManager(object):
             an iterator of DataManager objects
         """
         assert isinstance(batch_size, int), "batch_size should be a natural number"
-        assert 0 < batch_size <= len(self)
+        if batch_size > len(self):
+            batch_size = len(self)
+        assert 0 < batch_size
         ds = self.clone()
         record_list = ds.record_list
         if shuffle:
