@@ -13,7 +13,7 @@ class Polygon(object):
         self.shape_type = 'polygon'
 
     def shape_as_polygon(self, points, shape_type):
-        assert shape_type in ['polygon', 'rectangle', 'circle', 'point']
+        assert shape_type in ['polygon', 'rectangle', 'circle', 'point', 'bbox']
         if None: pass
         elif shape_type == 'polygon':
             return points
@@ -25,6 +25,11 @@ class Polygon(object):
             x1,y1 = points[0]
             x2,y2 = points[1]
             return [[x1,y1],[x1,y2],[x2,y2],[x2,y1]]
+        elif shape_type == 'bbox':
+            assert len(points) == 4, f"bbox must be x,y,x,y {points}"
+            x1,y1 = points[:2]
+            x2,y2 = points[2:]
+            return [[x1,y1],[x1,y2],[x2,y2],[x2,y1]]
         elif shape_type == 'circle':
             x0,y0 = points[0]
             x1,y1 = points[1]
