@@ -1,17 +1,20 @@
+import re
 import cv2
 import sys
 import cv2 as cv
+from mtutils.utils_vvd.box_processing import get_xyxy
 import numpy as np
 import PIL.Image as Image
 
 import matplotlib
 import matplotlib.pyplot as plt
 
-from .utils import vvd_round
+from .utils import is_number, vvd_round
 from .utils import is_path_obj
 from .utils import current_system
 from .utils import is_integer
 from .utils import OS_exists
+from .utils import time_reduce
 from .utils import glob_recursively
 
 from tqdm import tqdm
@@ -39,6 +42,10 @@ def show_hist(img):
 def image_resize(img_source, shape=None, factor=None, unique_check=False, interpolation=None):
     image_H, image_W = img_source.shape[:2]
     if shape is not None:
+        if is_number(shape):
+            shape = [shape] * 2
+        shape = vvd_round(shape)
+
         resized_image = cv2.resize(img_source, shape)
 
     elif factor is not None:
@@ -773,11 +780,13 @@ def apply_gimp_brightness_contrast(input_img, brightness = 0, contrast = 0):
 
     return buf
 
-def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None):
+def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None, w_min=None, w_max=None, h_min=None, h_max=None):
     image = to_gray_image(image)
     image = (image != 0).astype('uint8')
     num, mark_img, info, _ = cv2.connectedComponentsWithStats(image)
-    if largest_num is not None:
+    if 0 < min_area < 1:
+        min_area = min_area * time_reduce(*image.shape[:2])
+    if largest_num is not None and num > 1:
         largest_num = max(0, min(vvd_round(largest_num), num - 1))
         pixel_array = info[:, -1][1:]
         index_array, _ = get_Several_MinMax_Array(pixel_array, -largest_num)
@@ -797,6 +806,18 @@ def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None):
                     pass
                 else:
                     continue
+                if w_min is not None:
+                    if sub_info[2] < w_min:
+                        continue
+                if w_max is not None:
+                    if sub_info[2] > w_max:
+                        continue
+                if h_min is not None:
+                    if sub_info[3] < h_min:
+                        continue
+                if h_max is not None:
+                    if sub_info[3] > h_max:
+                        continue
             mark_img[mark_img == index] = - index
     res_img = (mark_img < 0).astype('uint8')
     return res_img
@@ -816,4 +837,101 @@ def close_connected_area(image, convex=False):
             else:
                 for contour in contours:
                     image = cv2.fillConvexPoly(image, contour, (1, 1, 1))
-    return image
\ No newline at end of file
+    return image
+
+
+def get_convexHull(mask):
+    contours, _ = cv2.findContours((mask != 0).astype('uint8'), 2, 1)
+    convexHull_points = cv2.convexHull(np.vstack(contours), clockwise=True).squeeze()
+    return convexHull_points
+
+
+def bounding_bbox(mask):
+    x, y, w, h =  cv2.boundingRect(get_convexHull(mask))
+    bbox = [x, y, x + w, y + h]
+    return bbox
+
+
+def get_kernal(ksize, shape='rec'):
+    """
+    ksize = [W, H]
+    shape in ['rec', 'circle', 'cross']
+    """
+
+    if is_number(ksize):
+        ksize = [ksize, ksize]
+
+    assert len(ksize) == 2 
+    ksize = vvd_round(ksize)
+    assert np.min(ksize) > 0, f"kernal size should be > 0, {ksize}"
+
+    if shape not in ['rec', 'circle', 'cross']:
+        shape = 'rec'
+    if shape == 'rec':
+        flag = cv2.MORPH_RECT
+    elif shape == 'circle':
+        flag = cv2.MORPH_ELLIPSE
+    elif shape == 'cross':
+        flag = cv2.MORPH_CROSS
+    else:
+        raise RuntimeError('unknown shape {shape}')
+    
+    kernal = cv2.getStructuringElement(flag, ksize)
+    return kernal
+
+
+def morphology_op(image, op, kernal_size, kermal_type=None):
+    """
+    op in ['open', 'close', 'eroid', 'dilate']
+    ksize = [W, H]
+    kermal_type in ['rec', 'circle', 'cross']
+    """
+    op_list = ['open', 'close', 'eroid', 'dilate']
+    assert op in op_list, f"op {op} not in {op_list}"
+    image = (image != 0).astype('uint8')
+    kernal = get_kernal(kernal_size, shape=kermal_type)
+    if op == 'open':
+        op_mark = cv2.MORPH_OPEN
+    elif op == 'close':
+        op_mark = cv2.MORPH_CLOSE
+    elif op == 'eroid':
+        op_mark = cv2.MORPH_ERODE
+    elif op == 'dilate':
+        op_mark = cv2.MORPH_DILATE
+    else:
+        raise RuntimeError(f"unknown op mark {op_mark}")
+
+    return cv2.morphologyEx(image, op_mark, kernal)
+    
+
+
+def eroid_op(image, kernal_size, kermal_type=None):
+    """
+    ksize = [W, H]
+    kermal_type in ['rec', 'circle', 'cross']
+    """
+    return morphology_op(image, 'eroid', kernal_size, kermal_type)
+
+
+def dilate_op(image, kernal_size, kermal_type=None):
+    """
+    ksize = [W, H]
+    kermal_type in ['rec', 'circle', 'cross']
+    """
+    return morphology_op(image, 'dilate', kernal_size, kermal_type)
+
+
+def open_op(image, kernal_size, kermal_type=None):
+    """
+    ksize = [W, H]
+    kermal_type in ['rec', 'circle', 'cross']
+    """
+    return morphology_op(image, 'open', kernal_size, kermal_type)
+
+
+def close_op(image, kernal_size, kermal_type=None):
+    """
+    ksize = [W, H]
+    kermal_type in ['rec', 'circle', 'cross']
+    """
+    return morphology_op(image, 'close', kernal_size, kermal_type)
\ No newline at end of file
