@@ -559,9 +559,11 @@ def draw_RB_map(y_true, y_pred, map_save_path=None):
 
 def histgrom(*data, bin_num=100):
     data_list = list(data)
+    value, bins = np.histogram(data_list, bins=bin_num)
     for data_item in data_list:
         plt.hist(data_item, bin_num)
     plt.show()
+    return value, bins
 
 
 def data_show(data):
@@ -669,7 +671,7 @@ def is_integer(num):
     """
     是否是整数，返回bool结果
     """
-    return isinstance(num, (int, np.int, np.int32, np.uint8, np.int16, np.int64))
+    return isinstance(num, (int, np.int, np.int32, np.uint8, np.int16, np.int64, np.intc))
 
 
 def is_float(num):
